@@ -23,6 +23,10 @@ from global_chem_extensions.software_adapters.networkx_adapter.networkx_adapter
 from global_chem_extensions.software_adapters.dimorphite_dl_adapter.dimorphite_dl import DimorphiteAdapter
 from global_chem_extensions.language_adapters.amino_acid_converter.amino_acid_converter import AminoAcidConverter
 
+# Validation
+
+from global_chem_extensions.validation.partial_smiles import PartialSmilesValidation
+
 # Monitors
 
 from global_chem_extensions.monitoring_services.database_monitor.database_monitor import DatabaseMonitor
@@ -265,7 +269,14 @@ class GlobalChemExtensions(object):
         spi.launch_app(host=host, port=port, debug=debugger)
 
     @staticmethod
-    def find_protonation_states(smiles_list, min_ph=6.4, max_ph=8.4, pka_precision=1.0, max_variants=128, label_states=False):
+    def find_protonation_states(
+            smiles_list,
+            min_ph=6.4,
+            max_ph=8.4,
+            pka_precision=1.0,
+            max_variants=128,
+            label_states=False
+    ):
 
         '''
 
@@ -287,4 +298,29 @@ class GlobalChemExtensions(object):
 
         states = dimorphite_adapter.run()
 
-        return states
\ No newline at end of file
+        return states
+
+    @staticmethod
+    def verify_smiles(
+            smiles_list,
+            partial=False,
+            return_failures=False
+    ):
+
+        '''
+
+        Arguments:
+            smiles_list (List): List of smiles
+            partial (Bool): whether the user would like to have partial fragments
+            return_failures (Bool): whether the user would like to have failures returned.
+
+        '''
+
+        psv = PartialSmilesValidation(partial=partial)
+
+        successes, failures = psv.validate(smiles_list)
+
+        if return_failures:
+            return successes, failures
+        else:
+            return successes
